@@ -6,34 +6,38 @@
 ## params:
 ##  l: list of MassPeaks objects
 ##  method: character, grouper to used (strict: don't allow multiple peaks of
-##          the same sample in the same bin, relaxed: allow them)
+##          the same sample in the same bin, relaxed: allow them, reference:
+##          group to reference sample == the first one)
 ##  tolerance: double, maximal deviation of a peak position to be
 ##             considered as same peak
 ##
 ## returns:
 ##  a list of adjusted MassPeaks objects
 ##
-binPeaks <- function(l, method=c("strict", "relaxed"), tolerance=0.002) {
+binPeaks <- function(l, method=c("strict", "relaxed", "reference"),
+                     tolerance=0.002) {
 
   ## test arguments
   .stopIfNotIsMassPeaksList(l)
 
   method <- match.arg(method)
 
+  ## store original mass sample number/id
+  nn <- lengths(l)
+  nonEmpty <- nn != 0L
+  samples <- rep.int(seq_along(l), nn)
+
   ## fetch all mass
-  mass <- unname(.unlist(lapply(l, function(x)x@mass)))
+  mass <- unname(.unlist(lapply(l[nonEmpty], function(x)x@mass)))
 
   ## fetch all intensities
-  intensities <- .unlist(lapply(l, function(x)x@intensity))
+  intensities <- .unlist(lapply(l[nonEmpty], function(x)x@intensity))
 
   ## fetch all snr
-  snr <- .unlist(lapply(l, function(x)x@snr))
-
-  ## store original mass sample number/id
-  samples <- rep.int(seq_along(l), lengths(l))
+  snr <- .unlist(lapply(l[nonEmpty], function(x)x@snr))
 
   ## sort values by mass
-  s <- sort.int(mass, method="quick", index.return=TRUE)
+  s <- sort.int(mass, index.return=TRUE)
 
   mass <- s$x
   intensities <- intensities[s$ix]
@@ -47,6 +51,9 @@ binPeaks <- function(l, method=c("strict", "relaxed"), tolerance=0.002) {
             },
             "relaxed" = {
               .grouperRelaxed
+            },
+            "reference" = {
+              .grouperRelaxedHighestAtReference
             }
   )
 
@@ -54,9 +61,9 @@ binPeaks <- function(l, method=c("strict", "relaxed"), tolerance=0.002) {
   mass <- .binPeaks(mass=mass, intensities=intensities, samples=samples,
                     tolerance=tolerance, grouper=grouper)
 
-  ## resort mass (order could change if "relaxed" is used)
-  if (method == "relaxed") {
-    s <- sort.int(mass, method="quick", index.return=TRUE)
+  ## resort mass (order could change if "relaxed"/"reference" is used)
+  if (method != "strict") {
+    s <- sort.int(mass, index.return=TRUE)
     mass <- s$x
     intensities <- intensities[s$ix]
     snr <- snr[s$ix]
@@ -67,12 +74,12 @@ binPeaks <- function(l, method=c("strict", "relaxed"), tolerance=0.002) {
   lIdx <- split(seq_along(mass), samples)
 
   ## create adjusted peak list
-  l <- .mapply(FUN=function(p, i) {
+  l[nonEmpty] <- .mapply(FUN=function(p, i) {
     p@mass <- mass[i]
     p@intensity <- intensities[i]
     p@snr <- snr[i]
     p
-  }, p=l, i=lIdx)
+  }, p=l[nonEmpty], i=lIdx)
 
   l
 }
